@@ -70,7 +70,7 @@ const char ScavengerRules   = 'S';
 enum {GoldSound, StepSound, ClimbSound, FallSound, DigSound, LadderSound, 
       DeathSound, CompletedSound, VictorySound, GameOverSound, NumSounds};
 
-/// Centralised message functions: implementations in kgrdialog.cpp.
+/// Centralized message functions: implementations in kgrdialog.cpp.
 class QWidget;
 class KGrMessage
 {
@@ -81,7 +81,7 @@ public:
     static int  warning     (QWidget * parent, const QString & caption,
                              const QString & text, const QString & label0,
                              const QString & label1,
-                             const QString & label2 = "");
+                             const QString & label2 = QString());
 };
 
 /// KGrGameData structure: contains attributes of a KGoldrunner game.
